# ceur-spt
RESTFul Single Point of Truth Server for CEUR-WS

[![Join the discussion at https://github.com/ceurws/ceur-spt/discussions](https://img.shields.io/github/discussions/ceurws/ceur-spt)](https://github.com/ceurws/ceur-spt/discussions)
[![pypi](https://img.shields.io/pypi/pyversions/pyCEURspt)](https://pypi.org/project/pyCEURspt/)
[![Github Actions Build](https://github.com/ceurws/ceur-spt/workflows/Build/badge.svg?branch=main)](https://github.com/ceurws/ceur-spt/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/pyCEURspt.svg)](https://pypi.python.org/pypi/pyCEURspt/)
[![GitHub issues](https://img.shields.io/github/issues/ceurws/ceur-spt.svg)](https://github.com/ceurws/ceur-spt/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/ceurws/ceur-spt.svg)](https://github.com/ceurws/ceur-spt/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/ceurws/ceur-spt.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Introduction
### CEUR-WS 
CEUR Workshop Proceedings (CEUR-WS.org)
Free Open-Access Proceedings for Computer Science Workshops
https://ceur-ws.org/
### Semantification of CEUR-WS
http://ceur-ws-browser.bitplan.com
http://ceur-ws.bitplan.com

### Single Point of Truth



